<!---
Please read this!

Before opening a new issue, make sure to search the existing issues for your problems, using the `bug` label :

https://gitlab.com/py3dtiles/py3dtiles/-/issues/?sort=created_date&state=opened&label_name%5B%5D=Bug&first_page_size=20
-->

## Summary

<!---
Please provide a brief description of the issue.
-->

## Steps to reproduce

<!--
Without any step to reproduce, qualifying or fixing bugs is very hard. Please
provide detailed steps to reproduce this bug. Attach any test case you have,
making it as minimal as possible.
-->

1.
1.
1.

**Expected behaviour**:

**Actual behaviour**:

<!--
Please attach the full output of py3dtiles if usage in command line, or the stacktrace, if relevant.
-->

## Informations

- OS (Linux, MacOS, Windows...) and version
- python version: ...
- py3dtiles version: ...

## Screenshots

<!---
Provide images and screenshots here.
-->
